<p align="center">
    <img alt="Shows the Power Comparison logo, a balance scale with two lightning bolts hovering above each side." src="https://raw.githubusercontent.com/hdert/Power-Comparison/main/src/power_comparison/img/power_compare.svg">
</p>
<p align="center">
    A modern Tkinter based app for comparing power plan prices!
</p>

<p align="center">
    <a href="https://pypi.org/project/power-comparison"><img src="https://img.shields.io/pypi/v/power-comparison.svg"></a>
    <a href="https://github.com/hdert/Power-Comparison/blob/main/LICENSE"><img src="https://img.shields.io/pypi/l/power-comparison.svg"></a>
</p>

# Table of Contents

-   [Getting Started](#getting-started)
    -   [Installation](#installation)
    -   [Usage](#usage)
-   [Contributing](#contributing)
    -   [Developing](#developing)
-   [License](#license)

# Getting Started

## Installation

Power Comparison is available as [`power-comparison`](https://pypi.org/project/power-comparison/) on PyPI:

```sh
# With pip
pip install power-comparison

# With pipx
pipx install power-comparison
```

## Usage

To run Power Comparison try:

```sh
power-comparison
```

# Contributing

Contributions are welcome and highly appreciated.

Contributions in the areas of power plan pricing data, and power retailer usage data downloaders would be extremely appreciated.

## Developing

Simply install [`hatch`](https://pypi.org/project/hatch) with:

```sh
pip install hatch
```

make your changes, and then try them out with:

```sh
hatch run power-comparison
```

# License

This repository is licensed under the [GPL-3.0 License](https://github.com/hdert/Power-Comparison/blob/main/LICENSE).
